USB Device JSON Configuration Examples 
=

This directory should contain device JSON configuration file examples.

Notes: 
-

When adding new schemas, remember to add their 'resourceType' and 'deviceClass' values to base.schema
or the unittests will fail.
